; docformat = 'rst'
;+
;
; .. _correct_nadir_amsu-v2.pro:
;
; =========================
; correct_nadir_amsu-v2.pro
; =========================
;
; routine permettant d'ajuster les donnees AMSU au nadir
;(correction de 2006 par F. Karbou)
; appelle interpol_correc.pro
;
; attention correction calculee pour les canaux tropospheriques
; (1  8 + 15 d'AMSUA)
;
; read :file:`${PROJECT_ID}/CORR_[LAND|SEA]_AMSU[AB]_JUIL2006.DAT`
; containing correction for land and sea. ++ ref. algo fatima karbou
;
; read :file:`${PROJECT_ID}//MASK/ETOPO1_Ice_g_gmt4.nc`
; d'ou on tire le type de surface pour chaque pixel (terre=1, mer=0)
; valeur land_sea_mask ajoute dans le fichier de sortie
;
; read :file:`${PROJECT_ID}/AMSU/yyyy/mm/dd/amsua[_amsub]_{yyyymmdd}_{geomin}_{geomax}.dat`
; produced by :ref:`extract_amsuab.pro`.
;
; write :file:`${PROJECT_ID}/AMSU/yyyy/mm/dd/amsua[_amsub]_{yyyymmdd}_{geomin}_{geomax}_nadir.dat`.
;
; .. only:: man
;
;    Figure is visible on PDF and HTML documents only.
;
; .. only:: html or latex
;
;     .. graphviz::
;
;        digraph correct_nadir_amsu {
;
;           amsu_a_cor_land [shape=diamond,fontname=Courier,label="${PROJECT_ID}/AMSU/CORR_LAND_AMSUA_JUIL2006.DAT"];
;           amsu_a_cor_sea [shape=diamond,fontname=Courier,label="${PROJECT_ID}/AMSU/CORR_SEA_AMSUA_JUIL2006.DAT"];
;           amsu_b_cor_land [shape=diamond,fontname=Courier,label="${PROJECT_ID}/AMSU/CORR_LAND_AMSUB_JUIL2006.DAT"];
;           amsu_b_cor_sea [shape=diamond,fontname=Courier,label="${PROJECT_ID}/AMSU/CORR_SEA_AMSUB_JUIL2006.DAT"];
;           mask [shape=diamond,fontname=Courier,label="${PROJECT_ID}/MASK/ETOPO1_Ice_g_gmt4.nc"];
;           amsu_t2 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax.dat"];
;           amsu_t3 [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax_nadir.dat"];
;
;           correct_nadir_amsu [shape=box,
;           fontname=Courier,
;           color=blue,
;           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/correct_nadir_amsu.pro",
;           label="${PROJECT}/src/correct_nadir_amsu.pro"];
;
;           {amsu_t2 mask amsu_a_cor_land amsu_a_cor_sea amsu_b_cor_land amsu_b_cor_sea} -> {correct_nadir_amsu} -> {amsu_t3};
;
;           }
;
; :Categories: AMSU
;
; :Params:
;   canal (string)
;   resol
;   lonmin
;   lonmax
;   latmin
;   latmax
;
;   bornes domaines necessaires pour le masque terre-mer
;
; :Also:
;
;  :ref:`data_amsu`, :ref:`data_bathymetry`
;
;  Called by :ref:`traite_amsuab.sh`
;
;  Previous step : :ref:`extract_amsuab.pro`
;
;  Next step : :ref:`amsu2ncdf.pro`
;
;  Use :ref:`interpol_correc.pro`, :func:`geolocation_to_string_idl`, 
;  :ref:`pixelsize.pro`
;  :ref: `interpolswath.pro`
;
; :Todo:
;
;
; verifier la correction nadir avec comparaison de traces des orbites
; avant / apres
;
; fichier (structure) issue de extract_amsua avec header contenant les
;infos utiles, mais pas encore de restriction de zone
;
; indentation du code
;
; :Examples:
;
;
;    canal='a5'
;    resol=1
;    lonmin=-60.
;    lonmax=50.
;    latmin=-30.
;    latmax=45.
;    correct_nadir_amsu, canal,resol, lonmin, lonmax, latmin, latmax
;
; :History:
;
; 2011/12/09 lelod
; test modif importante pour coherence avec nouveau traitement
;extract_amsu.pro (amsua pour le moment)
; deplacement de l'interpolation des points dans la fauchee de
;extract a correct_nadir
; definition de la zone et ecriture  du fichier "ameliore"(!)
;
; $Id: correct_nadir_amsu.pro 436 2011-11-25 17:48:35Z lelod $
;
; $URL: svn+ssh://lelod@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/correct_nadir_amsu.pro $
;
; - lelod 20111121 correction lecture du fichier pour tenir compte
;   nouveau parametre introduit : orbit (montante = 0, descendante =1)
; 
; - fplod 20111103T114723Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * fix header
;   * remove trailing blanks
;
; - lelod 20/10/2011
;
;   * calcul des tailles des pixels renvoye dans la fonction pixelsize
;   * modif de interpol_correc, qui appelle lui aussi pixelsize, et ne
;     sort plus ces informations lui meme
;   * modification pour utilisation de la bathymetrie dans le cas use_amsua=1
;
; - pinsard 2011-08-18T12:38:20Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * replace 1000000L by a call to file_lines()
;
; - pinsard 2011-08-17T14:58:13Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * use geolocation_to_string_idl
;
; - pinsard 2011-08-10T11:45:31Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * remove blank in input/output filenames
;
; - fplod 20110810T073601Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * recover informations from correct_nadir_LE06.pro (graph, examples,
;     history)
;
; - lelod 201108??
;
;   * creation by copy/paste correct_nadir_LE06.pro
;   * remove use_amsub parameter
;   * change outputs fields
;
; - pinsard 2011-05-30T15:44:37Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * [] must now be used for array
;   * re-do previous modif !!!
;   * arguments for domdef
;   * correct path for mask file
;
; - pinsard 2011-05-05T09:12:30Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * correction in graphviz
;
; - fplod 20110422T162217Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * example from traite_amsuab.sh
;   * prepare usage of PROJECT
;
; - fplod 20100723T114518Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * add graph
;   * add `AMSU/yyyy/mm` in path
;
;-
PRO correct_nadir_amsu, canal, resol, lonmin, lonmax, latmin, latmax
;
compile_opt idl2, strictarrsubs
;
@cm_project
;
; bornes de validite des donnees de Tb:encore en dur...

tbmin=100
tbmax=350


; lecture fichier land - sea (S. Masson)
file=project_id_env+'/MASK/ETOPO1_Ice_g_gmt4.nc'
domdef,lonmin, lonmax, latmin, latmax

bate = ncdf_lec(file, var = 'z') GT 0
xxe = float(ncdf_lec(file, var = 'lon'))
yye = float(ncdf_lec(file, var = 'lat'))
jpie = n_elements(xxe)
jpje = n_elements(yye)

; extraction zone donnees AMSU 
domdef,lonmin,lonmax,latmin,latmax
bate = ncdf_lec(file, var = 'z') GT 0
xxe = float(ncdf_lec(file, var = 'lon'))
yye = float(ncdf_lec(file, var = 'lat'))
jpie = n_elements;module lecture fichier a introduire ici



; lecture fichier jour
; decodage header
; 
; a modifier en fonction du module de lecture


month=tab[0,*]
yrday=tab[1,*]
orbit=tab[2,*]
hour=tab[3,*]
nosat=tab[4,*]
fov=tab[5,*]
lon=tab[6,*]
lat=tab[7,*]
zen=tab[8,*]

ch=tab[9,*] : les tbs lues
nn=max(size(ach))
; appel au ssprgm qui interpole les fonctions de correction
interpol_correc,nomcanal,nbpix,cor_l,cor_s

landseamask=intarr(nn)

;print, 'correction des observations au nadir'

for i=0L, nn-1L do begin
   ifov=fov[i]-1 ; fov est INTEGER
; approximation: 1km= 1deg/100, et on considere le quart en lon et lat
; de la surface du pixel pour optimiser la localisation du centre du
; pixel attention approximation brutale des distances en fractions dedegre
; recherche de la cote par rapport a la resolution AMSUA
   xind=where (xxe ge lon[i]-swatha[ifov]/400. and xxe le lon[i]+swatha[ifov]/400.,nxlandsea)
   yind=where (yye ge lat[i]-tracka[ifov]/400. and yye le lat[i]+tracka[ifov]/400.,nylandsea)
   if(nxlandsea ne 0 and nylandsea ne 0) then begin
      bate1=bate[xind,*]
      bate2=bate1[*,yind]
      if (mean(bate2) le 0.5) then begin
         ch_adj[i]=ch[i]-cor_sa[numcanal,ifov]
         landseamask[i]=0
      endif else begin
         ch_adj[i]=ch[i]-cor_lb[numcanal,ifov]
         landseamask[i]=1
      endelse
   endif
endfor 
;;correction des valeurs aberrantes
;et ecriture du fichier resultant
;
ind=where(landseamask eq 0)
                
 print, '#correct_nadir_amsu# ecriture du fichier resultant ', fichier2

for i=0L, nn-1L do begin
            if (( ch[i] lt tbmin) or (ch[i] gt tbmax) ) then begin
               ch_adj[i]=!values.f_nan
           endif
endfor



; appel a interpolswatw pour ajuster les pixels amsua sur une grille
; reguliere dans la fauchee
; et selection de la zone conservee
resol=1
   tb=fltarr(nbpix)
   lon=fltarr(nbpix)
   lat=fltarr(nbpix)
tt=hour[0]
ifov=0
for i=0L,n_scan-1L do begin
  ; reperage des fauchees : temps constant - faut il aussi test sur fov?
   while(hour[i] eq tt) do begin
      lon[ifov]=lonlu[i]
      lat[ifov]=latlu[i]
      tb[ifov]=ch_adj[i]
      ifov=ifov+1
   endwhile
   if (ifov eq nbpix) do begin
      interpolswath,tb,lat,lon,resol,nbgrid,tbgrid,latgrid,longrid
      zone=where((longrid ge lonmin) and (longrid le lonmax) $
             and (latgrid ge latmin) and (latgrid le latmax),npt)
      if npt ne 0 then begin
         temps[zone]=hour[i]
         chint=[chint,tbgrid[zone]]
         latint=[latint,latgrid[zone]]
         lonint=[lonint,longrid[zone]]
         fovint=[fovint,fovgrid[zone]]
         timeint=[timeint,temps[zone]]
      endif
   endif
   ifov=0
 endfor


; ecriture fichier sortie avec nbgrid valeurs dans la fauchee



      printf,lun_obsa, month[i],landseamask[i],yrday[i],orbit[i],hour[i],fov[i],nosat[i],lon[i],lat[i],zen[i],$
		  ;   ach1_adj[i],ach2_adj[i],ach3_adj[i],ach4_adj[i],ach5_adj[i],ach6_adj[i],ach7_adj[i],$
		  ;   ach8_adj[i],ach15_adj[i],bch1_adj[i],bch2_adj[i],bch3_adj[i],bch4_adj[i],bch5_adj[i],$
		  ;  format='(4(i3,1x),f8.4,2i3,20(1x,f8.3))'
   endif else begin

       printf,lun_obsa, month[i],landseamask[i],yrday[i],orbit[i],hour[i],fov[i],nosat[i],lon[i],lat[i],zen[i],$
		    bch1_adj[i],bch2_adj[i],bch3_adj[i],bch4_adj[i],bch5_adj[i],$
		    format='(4(i3,1x),f8.4,2i3,8(1x,f8.3))'
   endelse
endfor


end
