; docformat = 'rst'
;+
;
; .. _correct_nadir_amsu.pro:
;
; ======================
; correct_nadir_amsu.pro
; ======================
;
; routine permettant d'ajuster les donnees AMSUA AMSUB au nadir (correction de 2006 par F. Karbou)
;
; attention correction calculee pour les canaux tropospheriques
; (1  8 + 15 d'AMSUA)
;
; read :file:`${PROJECT_ID}/CORR_[LAND|SEA]_AMSU[AB]_JUIL2006.DAT`
; containing correction for land and sea. ++ ref. algo fatima karbou
;
; read :file:`${PROJECT_ID}//MASK/ETOPO1_Ice_g_gmt4.nc`
; d'ou on tire le type de surface pour chaque pixel (terre=1, mer=0)
; valeur land_sea_mask ajoute dans le fichier de sortie
;
; read :file:`${PROJECT_ID}/AMSU/yyyy/mm/dd/amsua[_amsub]_{yyyymmdd}_{geomin}_{geomax}.dat`
; produced by :ref:`extract_amsuab.pro`.
;
; write :file:`${PROJECT_ID}/AMSU/yyyy/mm/dd/amsua[_amsub]_{yyyymmdd}_{geomin}_{geomax}_nadir.dat`.
;
; .. only:: man
;
;    Figure is visible on PDF and HTML documents only.
;
; .. only:: html or latex
;
;     .. graphviz::
;
;        digraph correct_nadir_amsu {
;
;           amsu_a_cor_land [shape=diamond,fontname=Courier,label="${PROJECT_ID}/AMSU/CORR_LAND_AMSUA_JUIL2006.DAT"];
;           amsu_a_cor_sea [shape=diamond,fontname=Courier,label="${PROJECT_ID}/AMSU/CORR_SEA_AMSUA_JUIL2006.DAT"];
;           amsu_b_cor_land [shape=diamond,fontname=Courier,label="${PROJECT_ID}/AMSU/CORR_LAND_AMSUB_JUIL2006.DAT"];
;           amsu_b_cor_sea [shape=diamond,fontname=Courier,label="${PROJECT_ID}/AMSU/CORR_SEA_AMSUB_JUIL2006.DAT"];
;           mask [shape=diamond,fontname=Courier,label="${PROJECT_ID}/MASK/ETOPO1_Ice_g_gmt4.nc"];
;           amsu_t2 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax.dat"];
;           amsu_t3 [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax_nadir.dat"];
;
;           correct_nadir_amsu [shape=box,
;           fontname=Courier,
;           color=blue,
;           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/correct_nadir_amsu.pro",
;           label="${PROJECT}/src/correct_nadir_amsu.pro"];
;
;           {amsu_t2 mask amsu_a_cor_land amsu_a_cor_sea amsu_b_cor_land amsu_b_cor_sea} -> {correct_nadir_amsu} -> {amsu_t3};
;
;           }
;
; :Categories: AMSU
;
; :Params:
;   use_amusa
;   yyyy
;   mm
;   lonmin
;   lonmax
;   latmin
;   latmax
;
;   bornes domaines necessaires pour le masque terre-mer
;
; :Also:
;
;  :ref:`data_amsu`, :ref:`data_bathymetry`
;
;  Called by :ref:`traite_amsuab.sh`
;
;  Previous step : :ref:`extract_amsuab.pro`
;
;  Next step : :ref:`amsu2ncdf.pro`
;
;  Use :ref:`interpol_correc.pro`, :func:`geolocation_to_string_idl`, 
;  :ref:`pixelsize.pro`
;
; :Todo:
;
;
; verifier la correction nadir avec comparaison de traces des orbites
; avant / apres
;
; rcuprer les nbpix de amsu-a et amsu-b pour viter le codage en dur ici
; (30 et 90)
;
; indentation du code
;
; :Examples:
;
; Using AMSU-A and AMSU-B ::
;
;    use_amsua=1
;    yyyy=2006
;    mm=8
;    dd=1
;    lonmin=-60.
;    lonmax=50.
;    latmin=-30.
;    latmax=45.
;    correct_nadir_amsu, use_amsua, yyyy, mm, dd, lonmin, lonmax, latmin, latmax
;
; Using AMSU-B only ::
;
;    use_amsua=0
;    yyyy=2006
;    mm=8
;    dd=1
;    lonmin=-60.
;    lonmax=50.
;    latmin=-30.
;    latmax=45.
;    correct_nadir_amsu, use_amsua, yyyy, mm, dd, lonmin, lonmax, latmin, latmax
;
; :History:
;
; $Id$
;
; $URL$
;
; - lelod 20111121 correction lecture du fichier pour tenir compte
;   nouveau parametre introduit : orbit (montante = 0, descendante =1)
; 
; - fplod 20111103T114723Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * fix header
;   * remove trailing blanks
;
; - lelod 20/10/2011
;
;   * calcul des tailles des pixels renvoye dans la fonction pixelsize
;   * modif de interpol_correc, qui appelle lui aussi pixelsize, et ne
;     sort plus ces informations lui meme
;   * modification pour utilisation de la bathymetrie dans le cas use_amsua=1
;
; - pinsard 2011-08-18T12:38:20Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * replace 1000000L by a call to file_lines()
;
; - pinsard 2011-08-17T14:58:13Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * use geolocation_to_string_idl
;
; - pinsard 2011-08-10T11:45:31Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * remove blank in input/output filenames
;
; - fplod 20110810T073601Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * recover informations from correct_nadir_LE06.pro (graph, examples,
;     history)
;
; - lelod 201108??
;
;   * creation by copy/paste correct_nadir_LE06.pro
;   * remove use_amsub parameter
;   * change outputs fields
;
; - pinsard 2011-05-30T15:44:37Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * [] must now be used for array
;   * re-do previous modif !!!
;   * arguments for domdef
;   * correct path for mask file
;
; - pinsard 2011-05-05T09:12:30Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * correction in graphviz
;
; - fplod 20110422T162217Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * example from traite_amsuab.sh
;   * prepare usage of PROJECT
;
; - fplod 20100723T114518Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * add graph
;   * add `AMSU/yyyy/mm` in path
;
;-
PRO correct_nadir_amsu, use_amsua, yyyy, mm, dd, lonmin, lonmax, latmin, latmax
;
compile_opt idl2, strictarrsubs
;
@cm_project
;
; bornes de validite des donnees de Tb:

tbmin=100
tbmax=350

; ++ je (lelod) ne sais pas comment lui passer ces infos en parametres
if (use_amsua eq 1) then begin
    nbpix=30
endif else begin
    nbpix=90
endelse
; chemin des fichiers d'ajustement au nadir pour AMSUA
cor_landa=project_id_env+'AMSU/CORR_LAND_AMSUA_JUIL2006.DAT'
cor_seaa=project_id_env+'AMSU/CORR_SEA_AMSUA_JUIL2006.DAT'
cor_la=fltarr(9,30)
cor_sa=fltarr(9,30)

openr, lun1,cor_landa, /get_lun, ERROR = error
IF (error NE 0) then begin
   ras = report(['eee : can not open for reading '$
         + '!C' $
         + 'code : ' + !ERROR_STATE.MSG $
         + filemsg])
   STOP
ENDIF


for i=0, 8 do begin
    readf, lun1, t1,t2,t3,t4,t5,$
      t6,t7,t8,t9,t10,$
      t11,t12,t13,t14,t15,$
      t16,t17,t18,t19,t20,$
      t21,t22,t23,t24,t25,$
      t26,t27,t28,t29,t30

    a=[t1,t2,t3,t4,t5,$
       t6,t7,t8,t9,t10,$
       t11,t12,t13,t14,t15,$
       t16,t17,t18,t19,t20,$
       t21,t22,t23,t24,t25,$
       t26,t27,t28,t29,t30]

    cor_la[i,*]=a
endfor
free_lun, lun1

openr, lun1,cor_seaa, /get_lun

for i=0, 8 do begin
    readf, lun1, t1,t2,t3,t4,t5,$
      t6,t7,t8,t9,t10,$
      t11,t12,t13,t14,t15,$
      t16,t17,t18,t19,t20,$
      t21,t22,t23,t24,t25,$
      t26,t27,t28,t29,t30

    a=[t1,t2,t3,t4,t5,$
       t6,t7,t8,t9,t10,$
       t11,t12,t13,t14,t15,$
       t16,t17,t18,t19,t20,$
       t21,t22,t23,t24,t25,$
       t26,t27,t28,t29,t30]
    cor_sa[i,*]=a
endfor
free_lun, lun1
; appel pixelsize pour recuperer les dimensions des taches au sol
pixelsize,swatha,swathb,tracka,trackb

; AMSUB
if (use_amsua eq 1) then begin
    ; fichiers correction resolution AMSUB a la resolution AMSUA
    cor_landb=project_id_env+'AMSU/CORR_LAND_AMSUB_JUIL2006.DAT'
    cor_seab=project_id_env+'AMSU/CORR_SEA_AMSUB_JUIL2006.DAT'
    cor_lb=fltarr(5,30)
    cor_sb=fltarr(5,30)
    cor_landb=project_id_env+'AMSU/CORR_LAND_AMSUB_JUIL2006.DAT'
    cor_seab=project_id_env+'AMSU/CORR_SEA_AMSUB_JUIL2006.DAT'

    openr, lun1,cor_landb, /get_lun
    for i=0, 4 do begin
        readf, lun1, t1,t2,t3,t4,t5,$
          t6,t7,t8,t9,t10,$
          t11,t12,t13,t14,t15,$
          t16,t17,t18,t19,t20,$
          t21,t22,t23,t24,t25,$
          t26,t27,t28,t29,t30

        a=[t1,t2,t3,t4,t5,$
           t6,t7,t8,t9,t10,$
           t11,t12,t13,t14,t15,$
           t16,t17,t18,t19,t20,$
       t21,t22,t23,t24,t25,$
       t26,t27,t28,t29,t30]
        cor_lb[i,*]=a
    endfor
    free_lun, lun1

    openr, lun1,cor_seab, /get_lun
    for i=0, 4 do begin
        readf, lun1, t1,t2,t3,t4,t5,$
          t6,t7,t8,t9,t10,$
          t11,t12,t13,t14,t15,$
          t16,t17,t18,t19,t20,$
          t21,t22,t23,t24,t25,$
          t26,t27,t28,t29,t30

        a=[t1,t2,t3,t4,t5,$
           t6,t7,t8,t9,t10,$
           t11,t12,t13,t14,t15,$
           t16,t17,t18,t19,t20,$
           t21,t22,t23,t24,t25,$
           t26,t27,t28,t29,t30]
        cor_sb[i,*]=a
    endfor
    free_lun, lun1

endif else begin
    ; tableaux corrections pleine resolution
    interpol_correc,cor_lb,cor_sb
endelse


; fichier land - sea (S. Masson)
file=project_id_env+'/MASK/ETOPO1_Ice_g_gmt4.nc'
domdef,lonmin, lonmax, latmin, latmax

bate = ncdf_lec(file, var = 'z') GT 0
xxe = float(ncdf_lec(file, var = 'lon'))
yye = float(ncdf_lec(file, var = 'lat'))
jpie = n_elements(xxe)
jpje = n_elements(yye)

; extraction zone donnees AMSU :passage en parametres
domdef,lonmin,lonmax,latmin,latmax
bate = ncdf_lec(file, var = 'z') GT 0
xxe = float(ncdf_lec(file, var = 'lon'))
yye = float(ncdf_lec(file, var = 'lat'))
jpie = n_elements(xxe)
jpje = n_elements(yye)

; le fichier d'observation AMSU
;==================================================
; lecture du fichier global (1 mois)
; genere par extract_amsuab (avec selection de zone)
;
if (use_amsua eq 1) then begin
   prefix='amsua_amsub_'
endif else begin
   prefix='amsub_'
endelse

look = 'filename'
scale = 1.
geomin = geolocation_to_string_idl(lonmin, latmin, look, scale)
geomax = geolocation_to_string_idl(lonmax, latmax, look, scale)
fichier1=project_id_env+ 'AMSU/' $
        + string(yyyy,format='(I4.4)') + '/' $
        + string(mm,format='(I2.2)')   + '/' $
        + prefix+string(yyyy,format='(I4.4)') $
        + string(mm,format='(I2.2)') $
        + string(dd,format='(I2.2)') + '_' $
        + geomin + '_' $
        + geomax $
        + '.dat'
fichier2=file_dirname(fichier1) + '/' $
        +file_basename(fichier1,'.dat') $
        +'_nadir.dat'

print, '#correct_nadir_amsu# debut lecture du fichier d''observations ', fichier1

openr,luna,fichier1,/get_lun

if (use_amsua eq 1) then begin
   tab=fltarr(23L,file_lines(fichier1))
endif else begin
   tab=fltarr(14L,file_lines(fichier1))
  ; landseamask=intarr(file_lines(fichier1))
endelse

cont=0L

while (not eof(luna)) do begin
    if (use_amsua eq 1) then begin
        readf,luna, month,yrday,orbit,hour,nosat,fov,lon,lat,zen,ach1,ach2,ach3,ach4,ach5,ach6,ach7,ach8,ach9,ach10,ach11,ach12,ach13,ach14,$
          ach15,bch1,bch2,bch3,bch4,bch5, format='(3(i3,1x),f8.4,2i3,23(1x,f8.3))'

        tab[*,cont]=[month,yrday,orbit,hour,nosat,fov,lon,lat,zen,ach1,ach2,ach3,ach4,ach5,ach6,ach7,ach8,$
          ach15,bch1,bch2,bch3,bch4,bch5]
    endif else begin
        readf,luna, month,yrday,orbit,hour,nosat,fov,lon,lat,zen,bch1,bch2,bch3,bch4,bch5,format='(3(i3,1x),f8.4,2i3,8(1x,f8.3))'

        tab[*,cont]=[month,yrday,orbit,hour,nosat,fov,lon,lat,zen,bch1,bch2,bch3,bch4,bch5]
    endelse
    cont=cont+1
endwhile

abs=indgen(cont,/float)
;print,'taille de abs', size(abs)

free_lun,luna
tab=tab[*,abs]

month=tab[0,*]
yrday=tab[1,*]
orbit=tab[2,*]
hour=tab[3,*]
nosat=tab[4,*]
fov=tab[5,*]
lon=tab[6,*]
lat=tab[7,*]
zen=tab[8,*]

if (use_amsua eq 1) then begin
    ach1=tab[9,*]
    ach2=tab[10,*]
    ach3=tab[11,*]
    ach4=tab[12,*]
    ach5=tab[13,*]
    ach6=tab[14,*]
    ach7=tab[15,*]
    ach8=tab[16,*]
    ach15=tab[17,*]; liste des canaux traites (1 a 8 et 15)
    bch1=tab[18,*]
    bch2=tab[19,*]
    bch3=tab[20,*]
    bch4=tab[21,*]
    bch5=tab[22,*]

    nn=n_elements(ach1)

    ach1_adj=fltarr(nn)
    ach2_adj=fltarr(nn)
    ach3_adj=fltarr(nn)
    ach4_adj=fltarr(nn)
    ach5_adj=fltarr(nn)
    ach6_adj=fltarr(nn)
    ach7_adj=fltarr(nn)
    ach8_adj=fltarr(nn)
    ach15_adj=fltarr(nn)

    bch1_adj=fltarr(nn)
    bch2_adj=fltarr(nn)
    bch3_adj=fltarr(nn)
    bch4_adj=fltarr(nn)
    bch5_adj=fltarr(nn)

endif else begin
    bch1=tab[9,*]
    bch2=tab[10,*]
    bch3=tab[11,*]
    bch4=tab[12,*]
    bch5=tab[13,*]
    nn=n_elements(bch1)

    bch1_adj=fltarr(nn)
    bch2_adj=fltarr(nn)
    bch3_adj=fltarr(nn)
    bch4_adj=fltarr(nn)
    bch5_adj=fltarr(nn)
endelse
    landseamask=intarr(nn)
; ici on applique une correction pour ajuster les observations au nadir aux canaux A et B
;============================================================================================

;print, 'correction des observations au nadir'
;window,0
for i=0L, nn-1L do begin
   ifov=fix(fov[i])-1
   if use_amsua eq 1 then begin
       ; approximation: 1km= 1deg/100, et on considere le quart en lon et lat
       ; de la surface du pixel pour optimiser la localisation du centre du
       ; pixel attention approximation brutale des distances en fractions dedegre
       ; recherche de la cote par rapport a la resolution AMSUA
       xind=where (xxe ge lon[i]-swatha[ifov]/400. and xxe le lon[i]+swatha[ifov]/400.,nxlandsea)
       yind=where (yye ge lat[i]-tracka[ifov]/400. and yye le lat[i]+tracka[ifov]/400.,nylandsea)
          if(nxlandsea ne 0 and nylandsea ne 0) then begin
             bate1=bate[xind,*]
             bate2=bate1[*,yind]
              if (mean(bate2) le 0.5) then begin
                  ach1_adj[i]=ach1[i]-cor_sa[0,ifov]
                  ach2_adj[i]=ach2[i]-cor_sa[1,ifov]
                  ach3_adj[i]=ach3[i]-cor_sa[2,ifov]
                  ach4_adj[i]=ach4[i]-cor_sa[3,ifov]
                  ach5_adj[i]=ach5[i]-cor_sa[4,ifov]
                  ach6_adj[i]=ach6[i]-cor_sa[5,ifov]
                  ach7_adj[i]=ach7[i]-cor_sa[6,ifov]
                  ach8_adj[i]=ach8[i]-cor_sa[7,ifov]
                  ach15_adj[i]=ach15[i]-cor_sa[8,ifov]
                  bch1_adj[i]=bch1[i]-cor_sb[0,ifov]
                  bch2_adj[i]=bch2[i]-cor_sb[1,ifov]
                  bch3_adj[i]=bch3[i]-cor_sb[2,ifov]
                  bch4_adj[i]=bch4[i]-cor_sb[3,ifov]
                  bch5_adj[i]=bch5[i]-cor_sb[4,ifov]
                  landseamask[i]=0
               endif else begin
                  ach1_adj[i]=ach1[i]-cor_la[0,ifov]
                  ach2_adj[i]=ach2[i]-cor_la[1,ifov]
                  ach3_adj[i]=ach3[i]-cor_la[2,ifov]
                  ach4_adj[i]=ach4[i]-cor_la[3,ifov]
                  ach5_adj[i]=ach5[i]-cor_la[4,ifov]
                  ach6_adj[i]=ach6[i]-cor_la[5,ifov]
                  ach7_adj[i]=ach7[i]-cor_la[6,ifov]
                  ach8_adj[i]=ach8[i]-cor_la[7,ifov]
                  ach15_adj[i]=ach15[i]-cor_la[8,ifov]
                  bch1_adj[i]=bch1[i]-cor_lb[0,ifov]
                  bch2_adj[i]=bch2[i]-cor_lb[1,ifov]
                  bch3_adj[i]=bch3[i]-cor_lb[2,ifov]
                  bch4_adj[i]=bch4[i]-cor_lb[3,ifov]
                  bch5_adj[i]=bch5[i]-cor_lb[4,ifov]
                  landseamask[i]=1
               endelse
            endif
       endif else begin
          ; on est a la resolution de amsub
          xind=where (xxe ge lon[i]-swathb[ifov]/400. and xxe le lon[i]+swathb[ifov]/400.,nxlandsea)
          yind=where (yye ge lat[i]-trackb[ifov]/400. and yye le lat[i]+trackb[ifov]/400.,nylandsea)
          if(nxlandsea ne 0 and nylandsea ne 0) then begin
             bate1=bate[xind,*]
             bate2=bate1[*,yind]
             if (mean(bate2) le 0.5) then begin
                  bch1_adj[i]=bch1[i]-cor_sb[0,ifov]
                  bch2_adj[i]=bch2[i]-cor_sb[1,ifov]
                  bch3_adj[i]=bch3[i]-cor_sb[2,ifov]
                  bch4_adj[i]=bch4[i]-cor_sb[3,ifov]
                  bch5_adj[i]=bch5[i]-cor_sb[4,ifov]
                  landseamask[i]=0
             endif else begin
                  bch1_adj[i]=bch1[i]-cor_lb[0,ifov]
                  bch2_adj[i]=bch2[i]-cor_lb[1,ifov]
                  bch3_adj[i]=bch3[i]-cor_lb[2,ifov]
                  bch4_adj[i]=bch4[i]-cor_lb[3,ifov]
                  bch5_adj[i]=bch5[i]-cor_lb[4,ifov]
                  landseamask[i]=1
               endelse
             endif
       endelse
endfor
;;correction des valeurs aberrantes
;et ecriture du fichier resultant
;
ind=where(landseamask eq 0)
  ;plot,fov[ind],ach5[ind],psym=3,/noerase, xstyle=1,ystyle=1,color=0
 ; oplot,fov[ind],ach5_adj[ind],psym=1
                
 
    print, '#correct_nadir_amsu# ecriture du fichier resultant ', fichier2

openw, lun_obsa, fichier2, /get_lun, ERROR=error
if (error NE 0) THEN BEGIN
    ras = report(['eee : can not open for writing '$
         + '!C' $
         + 'code : ' + !ERROR_STATE.MSG $
         + fichier2])
   STOP
ENDIF
for i=0L, nn-1L do begin
    if (use_amsua eq 1) then begin
            if (( ach1[i] lt tbmin) or (ach1[i] gt tbmax) ) then begin
               ach1_adj[i]=!values.f_nan
           endif

           if (( ach2[i] lt tbmin) or (ach2[i] gt tbmax) ) then begin
               ach2_adj[i]=!values.f_nan
           endif

           if (( ach3[i] lt tbmin) or (ach3[i] gt tbmax) ) then begin
               ach3_adj[i]=!values.f_nan
           endif

           if (( ach4[i] lt tbmin) or (ach4[i] gt tbmax) ) then begin
               ach4_adj[i]=!values.f_nan
           endif

           if (( ach5[i] lt tbmin) or (ach5[i] gt tbmax) ) then begin
               ach5_adj[i]=!values.f_nan
           endif

           if (( ach6[i] lt tbmin) or (ach6[i] gt tbmax) ) then begin
               ach6_adj[i]=!values.f_nan
           endif

           if (( ach7[i] lt tbmin) or (ach7[i] gt tbmax) ) then begin
               ach7_adj[i]=!values.f_nan
           endif

           if (( ach8[i] lt tbmin) or (ach8[i] gt tbmax) ) then begin
               ach8_adj[i]=!values.f_nan
           endif

           if (( ach15[i] lt tbmin) or (ach15[i] gt tbmax) ) then begin
               ach15_adj[i]=!values.f_nan
           endif
   endif
    if (( bch1[i] lt tbmin) or (bch1[i] gt tbmax) ) then begin
	bch1_adj[i]=!values.f_nan
   endif

   if (( bch2[i] lt tbmin) or (bch2[i] gt tbmax) ) then begin
	bch2_adj[i]=!values.f_nan
   endif

   if (( bch3[i] lt tbmin) or (bch3[i] gt tbmax) ) then begin
	bch3_adj[i]=!values.f_nan
   endif

   if (( bch4[i] lt tbmin) or (bch4[i] gt tbmax) ) then begin
	bch4_adj[i]=!values.f_nan
   endif

   if (( bch5[i] lt tbmin) or (bch5[i] gt tbmax) ) then begin
	bch5_adj[i]=!values.f_nan
   endif
   if (use_amsua eq 1) then begin
 
      printf,lun_obsa, month[i],landseamask[i],yrday[i],orbit[i],hour[i],fov[i],nosat[i],lon[i],lat[i],zen[i],$
		  ;   ach1_adj[i],ach2_adj[i],ach3_adj[i],ach4_adj[i],ach5_adj[i],ach6_adj[i],ach7_adj[i],$
		  ;   ach8_adj[i],ach15_adj[i],bch1_adj[i],bch2_adj[i],bch3_adj[i],bch4_adj[i],bch5_adj[i],$
		  ;  format='(4(i3,1x),f8.4,2i3,20(1x,f8.3))'
   endif else begin

       printf,lun_obsa, month[i],landseamask[i],yrday[i],orbit[i],hour[i],fov[i],nosat[i],lon[i],lat[i],zen[i],$
		    bch1_adj[i],bch2_adj[i],bch3_adj[i],bch4_adj[i],bch5_adj[i],$
		    format='(4(i3,1x),f8.4,2i3,8(1x,f8.3))'
   endelse
endfor
free_lun, lun_obsa

end
