; docformat = 'rst'
;+
; .. _create_amsu_netcdf.pro:
;
; ======================
; create_amsu_netcdf.pro
; ======================
;
; DESCRIPTION
; ===========
;
; Creation du fichier NetCDF contenant AMSU Brightness Temperatures
;
; SEE ALSO
; ========
;
; Called by :ref:`amsu2ncdf.pro`
;
; Use : :func:`julday <saxo:julday>`, :func:`caldat <saxo:caldat>`
;
; EXAMPLES
; ========
;
; ::
;
;   file_ncdf='ginette.nc'
;   yyyy=2006
;   mm=1
;   dd=20
;   hh=11
;   mn=30
;   ss=30
;   lons=findgen(10)-10
;   lats=findgen(10)+20
;   datatab=findgen(10,10)
;   masktab=findgen(10,10)
;   create_amsu_netcdf, file_ncdf, yyyy, mm, dd, hh, mn, ss, lons, lats, datatab, masktab
;
; TODO
; ====
;
; check for some values in datatab : no if only missing values, can compute
; range of data
;
; realistic examples
;
; EVOLUTIONS
; ==========
;
; $Id: create_amsu_netcdf.pro 335 2011-08-10 09:46:39Z pinsard $
;
; $URL$
;
; - pinsard 2011-05-30T15:28:02Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * CF 1.5 
;     checker avaialble on http://puma.nerc.ac.uk/cgi-bin/cf-checker.pl
;
; - pinsard 2011-05-30T13:20:36Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * add mn ans dd parameters
;
; - fplod 20110530T104717Z cratos.locean-ipsl.upmc.fr (Linux)
;
;   * no more warning/errors when checking CF 1.4
;     see http://cf-pcmdi.llnl.gov/documents/cf-conventions/1.4/cf-conventions.html
;     nb : no compliance checker on version 1.5 available
;   * replace yday by mm and dd parameters
;
;   * time unit : hours since 19600101 (like MSG file created by create_nc.jnl)
;
; - pinsard 2011-05-27T10:14:10Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * remove creator attribute
;   * add compile_opts
;   * add a silly example
;
; - fplod 20110422T162433Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * prepare usage of PROJECT
;
; - fplod 20110121T150351Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * split of amsu2ncdf.pro
;
;-
pro create_amsu_netcdf $
    , file_ncdf, yyyy, mm, dd, hh, mn, ss, lons, lats, datatab, masktab
;
compile_opt idl2, strictarrsubs
;
@cm_project
;
; set debug to 1 to print info
debug=0
;
; ----------------------------
; Declaration des variables
; ----------------------------
nblondata=n_elements(lons)
nblatdata=n_elements(lats)
caldat, julday(1,1,1960,0,0,0),mtime_org,dtime_org,ytime_org,htime_org,mmtime_org, stime_org
timetab=(julday(mm,dd,yyyy,hh,mn,ss)-julday(mtime_org,dtime_org,ytime_org,htime_org,mmtime_org, stime_org))*24d

; ----------------------------
; Ouverture du fichier NetCDF
; ----------------------------
print, 'create file ', file_ncdf
id = NCDF_CREATE(file_ncdf,/CLOBBER)

; ----------------------------
; Creation des dimensions
; ----------------------------
dtime_id = NCDF_DIMDEF(id, 'time', /UNLIMITED)
dlong_id = NCDF_DIMDEF(id, 'lon', nblondata)
dlatd_id = NCDF_DIMDEF(id, 'lat', nblatdata)

; ----------------------------
; Creation des Definitions
; ----------------------------
;
; Definition des attributs globaux :
; ----------------------------------
NCDF_ATTPUT, id, /GLOBAL, 'Conventions', 'CF-1.5'
NCDF_ATTPUT, id, /GLOBAL, 'title', 'AMSU Brightness Temperatures'
;
; Variable : Temps :
; ------------------
time_id = NCDF_VARDEF(id, 'time', [dtime_id], /double)
NCDF_ATTPUT, id, time_id, 'units', $
    STRING(format = '("hours since ",I4.4,"-",I2.2,"-",I2.2," ",I2.2,":",I2.2,":",I2.2," UTC")', $
    ytime_org, mtime_org, dtime_org, htime_org, mmtime_org, stime_org)
NCDF_ATTPUT, id, time_id, 'calendar', 'standard'
NCDF_ATTPUT, id, time_id, 'long_name', 'Time'
NCDF_ATTPUT, id, time_id, 'actual_range', [min(timetab),max(timetab)], /double
;
; Variable : Latitude :
; ---------------------
latd_id = NCDF_VARDEF(id, 'lat', [dlatd_id], /float)
NCDF_ATTPUT, id, latd_id, 'units', 'degrees_north'
NCDF_ATTPUT, id, latd_id, 'long_name', 'Latitude'
NCDF_ATTPUT, id, latd_id, 'actual_range', [min(lats),max(lats)]
;
; Variable : Longitude :
; ----------------------
long_id = NCDF_VARDEF(id, 'lon', [dlong_id], /float)
NCDF_ATTPUT, id, long_id, 'units', 'degrees_east'
NCDF_ATTPUT, id, long_id, 'long_name', 'Longitude'
NCDF_ATTPUT, id, long_id, 'actual_range', [min(lons),max(lons)], /float
;
; Variable : data :
; -----------------
data_id = NCDF_VARDEF(id, 'tbch5b', [dlong_id,dlatd_id,dtime_id], /float)
NCDF_ATTPUT, id, data_id, 'units', "Kelvin"
NCDF_ATTPUT, id, data_id, 'long_name', "AMSU-B Channel 5 Brightness Temperature"
NCDF_ATTPUT, id, data_id, 'valid_range', [100,500]
if (debug eq 1) then begin
   print, 'dans create_amsu_netcdf'
   help, datatab
   datatab_novm=where(datatab ne -999.)
   help, datatab_novm
endif
NCDF_ATTPUT, id, data_id, 'actual_range', [min(datatab[where(datatab ne -999.)]),max(datatab[where(datatab ne -999.)])]
NCDF_ATTPUT, id, data_id, 'missing_value', -999.
NCDF_ATTPUT, id, data_id, '_FillValue', -999.
;
; Variable : Mask :
; -----------------
mask_id = NCDF_VARDEF(id, 'mask', [dlong_id,dlatd_id,dtime_id], /float)
NCDF_ATTPUT, id, mask_id, 'units', '1'
NCDF_ATTPUT, id, mask_id, 'long_name', "land-sea mask, 1 all land, 0 all sea"
NCDF_ATTPUT, id, mask_id, 'valid_range', [0,1]
NCDF_ATTPUT, id, mask_id, 'actual_range', [min(masktab[where(datatab ne -999.)]),max(masktab[where(datatab ne -999.)])]
NCDF_ATTPUT, id, mask_id, 'missing_value', -999.
NCDF_ATTPUT, id, mask_id, '_FillValue', -999.

NCDF_CONTROL, id, /ENDEF

; ----------------------------
; Creation des Variables
; ----------------------------
NCDF_VARPUT, id, time_id, timetab
NCDF_VARPUT, id, latd_id, lats
NCDF_VARPUT, id, long_id, lons
NCDF_VARPUT, id, data_id, datatab
NCDF_VARPUT, id, mask_id, masktab
;
; fermeture du fichier NetCDF :
; -----------------------------
NCDF_CLOSE, id

end
