function [geolocation_string] = geolocation_to_string(lon_value, lat_value)

%GEOLOCATION_TO_STRING build a string from a geolocation(lon,lat) using
%convention

%
%+
%
% =======================
% geolocation_to_string.m
% =======================
%
%
% .. function:: geolocation_to_string(lon_value, lat_value)
%
% DESCRIPTION
% ===========
%
%    :param lon_value: longitude, W < 0
%    :units lon_value: deg
%    :type lon_value: double
%    :raise lon_value: required
%
%    :param lat_value: latitude, N > 0
%    :units lat_value: deg
%    :type lat_value: double
%    :raise lat_value: required
%
%    :returns: a string or ++ if error
%    :rtype: string
%
% Build a string using W, E, S or N according to values of latitude and 
% longitude
%
% EXAMPLES
% ========
%
% see demos
%
% SEE ALSO
% ========
%
% equivalent fonctionality :
% :func:`geolocation_to_string_idl` (IDL)
% :ref:`geolocation_to_string_sh.sh` (shell script)
%
% TODO
% ====
%
% parameter convention ?
%
% parameter precision (nb de digit aprs la virgule dans la chaine)
%
% parameter "for title of figure" vs "for file name"
%
% return values in case of error
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/geolocation_to_string.m $
%
% - pinsard 2011-08-18T07:14:31Z loholt1.ipsl.polytechnique.fr (Linux)
%
%   * reverse lat/lon order
%   * add reference to :func:`geolocation_to_string_idl` and 
%     :ref:`geolocation_to_string_sh.sh`.
%
% - fplod 20110302T120611Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * usage of fail in tests (need to change stdout/stderr ... still wondering)
%
% - fplod 20110223T114433Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add test and demo
%
% - fplod 20110223T100120Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation
%
%-
geolocation_string=NaN;
%
usage='[geolocation_string] = geolocation_to_string(lon_value, lat_value)';
%
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage);
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('lon_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg lon_value ' arg_info.class]);
   whos lon_value
   error(usage);
end
%
% +todo+ check only one lon_value
%
arg_info=whos('lat_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg lat_value ' arg_info.class]);
   whos lat_value
   error(usage);
end
clear arg_info
%
% +todo+ check only one lat_value
if (isnan(lon_value))
   disp(usage);
   error(['eee : ' mfilename ' : lon_value NaN']);
end
%
if (isnan(lat_value))
   disp(usage);
   error(['eee : ' mfilename ' : lat_value NaN']);
end
%
% +todo+ traduction trouver les points cardinaux N or S and E or W
if (lon_value > 0.)
   west_east='E';
else
   west_east='W';
end
if (lat_value > 0.)
   south_north='N';
else
   south_north='S';
end
%
% convertion lon and lat absolute values to string
lon_string=num2str(abs(lon_value),'%7.2f');
lat_string=num2str(abs(lat_value),'%6.2f');
%
sep=',';
unit_string='';
%
% build the result
geolocation_string=sprintf('%s%s%s%s%s%s%s',lon_string,unit_string,south_north,sep,lat_string,unit_string,west_east);
%
clear sep
clear unit_string
clear lon_string
clear lat_string
clear west_east
clear south_north
%
whos
%
end

%!demo
%! lon_value = -10.;
%! lat_value = 10.;
%! geolocation_string = geolocation_to_string(lon_value,lat_value)

%!test
%! lon_value = -10.;
%! lat_value = 10.;
%! result = '10.00W,10.00N';
%! assert(strcmp(geolocation_to_string(lon_value,lat_value),result));

%!test
%! lon_value = -10.;
%! lat_value = NaN;
%! fail('geolocation_to_string(lon_value,lat_value)', 'eee : geolocation_to_string : lat_value NaN')

%!test
%! lon_value = NaN;
%! lat_value = 10.;
%! fail('geolocation_to_string(lon_value,lat_value)', 'eee : geolocation_to_string : lon_value NaN')
