#! /bin/sh
#+
#
# .. program:: geolocation_to_string_sh.sh
#
# .. _geolocation_to_string_sh.sh:
#
# ===========================
# geolocation_to_string_sh.sh
# ===========================
#
# SYNOPSIS
# ========
#
# ::
#
#  $ geolocation_to_string_sh.sh -lon lon -lat lat
#
# DESCRIPTION
# ===========
#
# .. option:: -lon lon
# .. option:: -lat lat
#
# ``geolocation_to_string_sh.sh`` produce a string that may be
# used in filename when latitudes and longitudes have been
# modified from orginal dataset.
#
# EXAMPLES
# ========
#
# You want the string to be used in files where latitudes and longitudes
# have been restricted to [25W, 25E], [5S,20N] ::
#
#   $ geolocation_to_string_sh.sh -lon -25 -lat -5
#   025w05s
#   $ geolocation_to_string_sh.sh -lon 25 -lat 20
#   025e20n
#
# In a shell script you can reuse these strings::
#
#   geomin=$(geolocation_to_string_sh.sh -lon -25 -lat -5)
#   status=${?}
#   if [ ${status} -ne 0 ]
#   then
#      exit 1
#   fi
#   geomax=$(geolocation_to_string_sh.sh -lon 25 -lat 20)
#   status=${?}
#   if [ ${status} -ne 0 ]
#   then
#      exit 1
#   fi
#   newfile='ginette_'${geomin}_${geomax}'.nc'
#
# SEE ALSO
# ========
#
# used in
# :ref:`traite_trmm.sh`
# :ref:`traite_amsuab.sh`
#
# equivalent fonctionality :
# :func:`geolocation_to_string_idl` with :samp:`look=filename` (IDL),
# :func:`geolocation_to_string` (matlab/octave) when :samp:`look=filename`
# wil be implemented.
#
# TODO
# ====
#
# check consistence of lat and lon
#
# transform into a function ... not so sure 
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# $URL$
#
# - pinsard 2011-08-18T06:57:44Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * rename from filelatlon.sh to geolocation_to_string_sh.sh
#     to homegenize with geolocation_to_string.m and
#     geolocation_to_string_idl.pro
#   * only 2 arguments (reduced from 4)
#   * suppress "_" between lon and lat
#   * correction of usage
#
# - pinsard 2011-06-06T14:35:36Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * creation
#
#-
system=$(uname)
case "${system}" in
   AIX|IRIX64)
     echo "www : no specific posix checking"
     date_cmd=date
   ;;
   Darwin)
     set -o posix
     date_cmd=gdate
   ;;
   Linux)
     set -o posix
     date_cmd=date
   ;;
   *)
    set -o posix
   ;;
esac
unset system
#
set -u
#
LANG=POSIX
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
#
usage=" Usage : ${command} -lon lon -lat lat"
#
hostname=$(hostname)
#
minargcount=4
if [ ${#} -lt ${minargcount} ]
then
   echo "eee : not enought arguments"
   echo "${usage}"
   exit 1
fi
unset minargcount
#
while [ ${#} -gt 0 ]
do
   case ${1} in
     -lon)
        lon=${2}
        shift
     ;;
     -lat)
        lat=${2}
        shift
     ;;
     -h)
        echo "${usage}"
        exit 0
     ;;
     *)
        # other choice
        echo "eee : unknown option ${1}"
        echo "${usage}"
        exit 1
     ;;
   esac
   # next flag
   shift
done
unset usage
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
echo "[Context]" 1>> ${log}
echo "command=$(basename ${0})" 1>>${log}
echo "hostname=${hostname}" 1>> ${log}
echo "runtime=${log_date}" 1>> ${log}
echo "log=${log}" 1>> ${log}
unset log_date
echo "" 1>> ${log}
echo "[Parameters]" 1>> ${log}
echo "lon=${lon}" 1>> ${log}
echo "lat=${lat}" 1>> ${log}
echo "" 1>> ${log}
#
if [ ${lon} -ge 0 ]
then
   lonletter='e'
else
   lonletter='w'
fi
if [ ${lat} -ge 0 ]
then
   latletter='n'
else
   latletter='s'
fi
#
lon_ns=$(echo ${lon} | sed -e "s/^-//" -e "s/^+//")
londigits=$(printf "%3.3d" ${lon_ns})
lat_ns=$(echo ${lat} | sed -e "s/^-//" -e "s/^+//")
latdigits=$(printf "%2.2d" ${lat_ns})

stringout=${londigits}${lonletter}
stringout="${stringout}${latdigits}${latletter}"
#
echo ${stringout}
#
# ++ unset
#end
exit 0
