#! /bin/sh
#+
#
# .. program:: varamma_profile.sh
#
# .. _varamma_profile.sh:
#
# ==================
# varamma_profile.sh
# ==================
#
# --------------------------
# define VARAMMA environment
# --------------------------
#
# SYNOPSIS
# ========
#
# Online usage::
#
#  $ . ./varamma_profile.sh -d directory -i indir -o outdir -t tempdir -s saxo_dir -idl_cmd idl_cmd
#
# In ${HOME}/.profile, add the following line::
#
#  . varamma_profile.sh -d directory  -i indir -o outdir -t tempdir -s saxo_dir
#
# DESCRIPTION
# ===========
#
# .. option:: -d  <directory>
# .. option:: -i  <indir>
# .. option:: -o  <outdir>
# .. option:: -t  <tempdir>
# .. option:: -s  <saxo_dir>
# .. option:: -idl_cmd  <idl_cmd>
#
# define VARAMMA environment
#
# ${VARAMMA} is the base directory of tools.
#
# ${VARAMMA_LOG} is the directory where log files will be written.
#
# ${VARAMMA_ID} is the directory where input files must be.
#
# ${VARAMMA_OD} is the directory where output files will be written.
#
# ${SAXO_DIR} is the base directory of SAXO tools
#
# PATH is completed with ${VARAMMA}/src/ and ${VARAMMA}/adm/.
#
# FER_GO is completed with ${VARAMMA}/src/.
#
# IDL_STARTUP is set to tell IDL where find tools.
#
# If :option:`-idl_cmd` is used, **idl_cmd** will be used as the IDL command when launched from
# scripts. By default, ${IDL_CMD} is set to `idl`. 
#
# MATLABPATH is initialize to tell matlab where find tools.
#
#
# SEE ALSO
# ========
#
# for matlab/octave environment :
#
# :ref:`varamma_startup.m`
#
# for IDL/gdl and SAXO environment :
#
# :ref:`project_init.pro`
# :ref:`cm_project.pro`
#
# EXAMPLES
# ========
#
# For fplod, on halios.locean-ipsl.upmc.fr with gdl::
#
#  cd /usr/home/fplod/incas/varamma/varamma_ws/
#  . ./src/varamma_profile.sh \
#    -d $(pwd) \
#    -i /usr/temp/${LOGNAME}/varamma_d/ \
#    -o /usr/temp/${LOGNAME}/varamma_d/ \
#    -t /usr/temp/${LOGNAME}/log/ \
#    -s /usr/home/fplod/SAXO_DIR/ \
#    -idl_cmd gdl
#
# For fplod on cratos.locean-ipsl.umpc.fr with default IDL version::
#
#  cd ${HOME}/incas/varamma/varamma_ws/
#  . ./src/varamma_profile.sh \
#    -d $(pwd) \
#    -i /usr/temp/${LOGNAME}/varamma_d/ \
#    -o /usr/temp/${LOGNAME}/varamma_d/ \
#    -t /usr/temp/${LOGNAME}/log/ \
#    -s ${HOME}/SAXO_DIR/
#
# For fplod on cratos.locean-ipsl.umpc.fr with IDL version 6.4::
#
#  cd ${HOME}/incas/varamma/varamma_ws/
#  . ./src/varamma_profile.sh \
#    -d $(pwd) \
#    -i /usr/temp/${LOGNAME}/varamma_d/ \
#    -o /usr/temp/${LOGNAME}/varamma_d/ \
#    -t /usr/temp/${LOGNAME}/log/ \
#    -s ${HOME}/SAXO_DIR/ \
#    -idl_cmd  /usr/local_linux/idl/idl_6.4/idl64/bin/idl
#
# For pinsard on camelot.ipsl.polytechnique.fr or merlin15-c.climserv::
#
#  cd ${HOME}/varamma/
#  . ./src/varamma_profile.sh \
#   -d $(pwd) \
#   -i /homedata/${LOGNAME}/varamma_d/ \
#   -o /homedata/${LOGNAME}/varamma_d/ \
#   -t /homedata/${LOGNAME}/log/ \
#   -s ${HOME}/SAXO_DIR/
#
# For pinsard on loholt1 to use idl 6-4::
#
#  cd ${HOME}/varamma/
#  . ./src/varamma_profile.sh \
#   -d $(pwd) \
#   -i /homedata/${LOGNAME}/varamma_d/ \
#   -o /homedata/${LOGNAME}/varamma_d/ \
#   -t /homedata/${LOGNAME}/log/ \
#   -s ${HOME}/SAXO_DIR/ \
#   -idl_cmd /opt/idl-6.4/idl/bin/idl
#
# .. todo::
#
# ++ option bavarde
#
# ++ machine dependant
#
# ++ besoin de posix
#
# usage of PROJECT* instead of VARAMMA* everywhere
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# - fplod/soclod 20111214
#
#   *  suppress TEXINPUTS definition : too many side effects
#
# - soclod/fplod 20111025
#
#   * MANPATH undefined by default on mac, same for FER_GO
#   * set +u status at the end of this script
#
# - fplod 20111007T144105Z cratos (Linux)
#
#   * TEXINPUTS might be undefined
#
# - pinsard 2011-08-22T14:22:39Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * add idl_cmd option
#
# - fplod 20110622T122143Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * add TEXINPUTS
#
# - fplod 20110422T153033Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * set IDL_STARTUP
#
# - fplod 20110422T132514Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * add SAXO environment
#   * prepare usage of PROJECT* instead of VARAMMA*
#   * replace zeus by cratos
#
# - fplod 20110302T144450Z
#
#   * add ${VARAMMA}/adm to PATH (needed for mlintall.sh)
#
# - fplod 20100813T160214Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * change MANTPATH
#
# - fplod 20100525T121247Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * ${VARAMMA}=working space (not working space/src)
#
# - fplod 20100525T095355Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * add SEE ALSO and set MATLABPATH
#
# - fplod 20100426T094821Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * improve PATH and MANPATH modification
#
# - fplod 20100423T143946Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * add error handling on mkdir
#
# - fplod 20100318T080202Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * unset
#
# - fplod 2009-04-16T07:59:46Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * remove MANPATH completion because no manuals (nroff) are produced yet.
#     and major bad side effect if MANPATH isn't defined because
#     in this case ``echo ${MANPATH} | grep -q ${VARAMMA}/man``
#     is waiting for non empty string to look at !
#
# - fplod 2009-04-08T13:34:07Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#  * add example for camelot and merlin15 (climserv)
#
# - fplod 2008-08-14T12:28:16Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#  * move all \*.sh and \*.pro files to src/
#
# - fplod 2008-07-21T10:58:47Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation
#
#-
system=$(uname)
case "${system}" in
   AIX|IRIX64)
      echo " www : no specific posix checking"
   ;;
   *)
      set -o posix
   ;;
esac
unset system
#
set -u
#
LANG=C
#
# as this script might be launch in .profile, command is forced.
command=varamma_profile.sh
#
usage="Usage : ${command} -d directory -i indir -o outdir -t tempdir -s saxo_dir [-idl_cmd idl_cmd]"
#
# default
idl_cmd=idl
#
while [ ${#} -gt 0 ]
do
   case ${1} in
      -d)
         # directory for application choosen by user (see svn checkout command used)
         directory=${2}
         shift
      ;;
      -i)
         # directory for inputs choosen by user
         indir=${2}
         shift
      ;;
      -o)
         # directory for outputs choosen by user
         outdir=${2}
         shift
      ;;
      -t)
         # directory for temporary outputs choosen by user
         tempdir=${2}
         shift
      ;;
      -s)
         # directory for SAXO tools
         saxo_dir=${2}
         shift
      ;;
      -idl_cmd)
         # command for idl
         idl_cmd=${2}
         shift
      ;;
      *)
         # other choice
         echo "eee : unknown option ${1}"
         echo "${usage}"
         # nb : no exit because this file should be launched by login process
      ;;
   esac
   # next flag
   shift
done
unset usage
#
# check for ${directory}
if [ ! -d ${directory} ]
then
   echo " eee : ${directory} not found"
   # nb : no exit because this file should be launched by login process
fi
#
# check for permission on directory
if [ ! -x ${directory} ]
then
   echo " eee : ${directory} not reachable"
   # nb : no exit because this file should be launched by login process
fi
#
VARAMMA=${directory}
export VARAMMA
unset drectory
#
# add VARAMMA tools to PATH
# if not already done
suppath=$(echo ${VARAMMA}/src | tr -s "/")
echo ${PATH} | grep -q "${suppath}:"
test_path=${?}
if [ ${test_path} -ne 0 ]
then
   PATH=${suppath}:${PATH}
   export PATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${suppath} already in \${PATH}"
fi
unset test_path
suppath=$(echo ${VARAMMA}/adm| tr -s "/")
echo ${PATH} | grep -q "${suppath}:"
test_path=${?}
if [ ${test_path} -ne 0 ]
then
   PATH=${suppath}:${PATH}
   export PATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${suppath} already in \${PATH}"
fi
unset test_path
#
# add VARAMMA manuals to MANPATH
# if not already done
suppath=$(echo ${VARAMMA}/doc/man | tr -s "/")
set +u
echo ${MANPATH} | grep -q "${suppath}:"
test_manpath=${?}
if [ ${test_manpath} -ne 0 ]
then
   MANPATH=${suppath}:${MANPATH}
   export MANPATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${suppath} already in \${MANPATH}"
fi
set -u
unset test_manpath
unset suppath
#
VARAMMA_LOG=${tempdir}
export VARAMMA_LOG
unset tempdir
if [ ! -d ${VARAMMA_LOG} ]
then
   mkdir -p ${VARAMMA_LOG}
   status=${?}
   if [ ${status} -ne 0 ]
   then
      echo "${command} : eee : can not create \${VARAMMA_LOG}"
      # nb : no exit because this file should be launched by login process
   else
      echo "${command} : iii : creation of \${VARAMMA_LOG}"
   fi
   unset status
fi
# check for permission on VARAMMA_LOG
if [ ! -x ${VARAMMA_LOG} ]
then
   echo " eee : ${VARAMMA_LOG} not reachable"
   # nb : no exit because this file should be launched by login process
fi
#
# check for permission on VARAMMA_LOG
if [ ! -w ${VARAMMA_LOG} ]
then
   echo " eee : ${VARAMMA_LOG} not writable"
   # nb : no exit because this file shouldreachable be launched by login process
fi
#
EDITOR=vi
export EDITOR
#
# io directories
VARAMMA_ID=${indir}
export VARAMMA_ID
unset indir
if [ ! -d ${VARAMMA_ID} ]
then
   mkdir -p ${VARAMMA_ID}
   echo "${command} : iii : creation of \${VARAMMA_ID}"
fi
# check for permission on VARAMMA_ID
if [ ! -x ${VARAMMA_ID} ]
then
   echo " eee : ${VARAMMA_ID} not reachable"
   # nb : no exit because this file should be launched by login process
fi
#
VARAMMA_OD=${outdir}
export VARAMMA_OD
unset outdir
if [ ! -d ${VARAMMA_OD} ]
then
    mkdir -p ${VARAMMA_OD}
    echo "${command} : iii : creation of \${VARAMMA_OD}"
fi
# check for permission on VARAMMA_OD
if [ ! -x ${VARAMMA_OD} ]
then
   echo " eee : ${VARAMMA_OD} not reachable"
   # nb : no exit because this file should be launched by login process
fi
if [ ! -w ${VARAMMA_OD} ]
then
   echo " eee : ${VARAMMA_OD} not writable"
   # nb : no exit because this file should be launched by login process
fi
#
# setup for ferret
set +u
FER_GO="${FER_GO} ${VARAMMA}/src"
export FER_GO
set -u
#
# setup for matlab
MATLABPATH=${VARAMMA}
export MATLABPATH
#
# set up for idl
IDL_CMD=${idl_cmd}
export IDL_CMD
unset idl_cmd
#
# SAXO environment
SAXO_DIR=${saxo_dir}
export SAXO_DIR
unset saxo_dir
#
PROJECT=${VARAMMA}
export PROJECT
PROJECT_ID=${VARAMMA_ID}
export PROJECT_ID
PROJECT_OD=${VARAMMA_OD}
export PROJECT_OD
PROJECT_LOG=${VARAMMA_LOG}
export PROJECT_LOG
#
# IDL startup
IDL_STARTUP=${PROJECT}/src/project_init.pro
export IDL_STARTUP
#
# end
unset command
set +u
# nb : no exit because this file should be launched by login process
