function [result]=write_lai(lon_value, lat_value, datestr_value, lai_value)

%WRITE_LAI write LAI file from LAI 3D array and associated arrays lat, lon, date

%
%+
%
% ===========
% write_lai.m
% ===========
%
% .. function:: write_lai(lon_value, lat_value, datestr_value, lai_value)
%
% DESCRIPTION
% ===========
%
%    :param lon_value: longitude array
%    :type lon_value: 1D array of floats
%    :raise lon_value: required
%
%    :param lat_value: latitude array
%    :type lat_value: 1D array of floats
%    :raise lat_value: required
%
%    :param datestr_value: date (yyyymmdd) array
%    :type datestr_value: 1D array of strings
%    :raise datestr_value: required
%
%    :param lai_value: LAI array
%    :type lai_value: 1D array of floats
%    :raise lai_value: required
%
% Write in a file :file:`${PROJECT_OD}/LAI/laisen{yyyy}_write_lai_float.txt` contents
% of 3D array of **lai_value**  for each date in **datestr_value**
% on each grid point defined by **lon_value** and **lat_value**.
%
% **datestr_value** are supposed to be in the same year.
%
% EXAMPLES
% ========
%
% From scratch to write some simulated LAI values in
% :file:`${PROJECT_OD}/LAI/laisen2001_write_lai_float.txt`::
%
%   $ octave
%   octave> varamma_startup
%   octave> more off
%   octave> index_simulation=uint8(1);
%   octave> [lon_value, lat_value, datestr_value, lai_value]=simul_lai(index_simulation);
%   octave> result=write_lai(lon_value, lat_value, datestr_value, lai_value);
%
% From real file :file:`${PROJECT_ID}/LAI/laisen2001_float.txt`::
%
%   $ octave
%   octave> varamma_startup
%   octave> more off
%   octave> yyyy=uint16(2001);
%   octave> [lon_value, lat_value, datestr_value, lai_value]=read_lai(yyyy);
%   octave> result=write_lai(lon_value, lat_value, datestr_value, lai_value);
%
% SEE ALSO
% ========
%
% :ref:`guide data LAI <data_lai>`
%
% :func:`simul_lai`
% :func:`read_lai`
%
% TODO
% ====
%
% ++ check arguments (type, size, value)
%
% status de retour
%
% EVOLUTIONS
% ==========
%
% $Id: write_lai.m 325 2011-08-04 15:30:01Z pinsard $
%
% $URL$
%
% - fplod 20101202T142947Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * new terminology and new format
%   * add parameter information in header
%
% - fplod 20100826T120800Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation because
%
%     - real files are big (193 Mo) so need some small LAI
%       data to test scientific application
%     - real files are no readable by :program:`QGIS` so we have to prepare
%       migration
%
%-

global PROJECT_OD;

result=-1;
usage='[result]=write_lai(lon_value, lat_value, datestr_value, lai_value)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
% ++ check arguments (type, size, values)
nb_lat=size(lat_value,2);
nb_lon=size(lon_value,2);
nb_datestr=size(datestr_value,2);

% calculate doy
datenum_value=zeros(nb_datestr,1);
datenum_value(:)=NaN;
for index_datestr=1:nb_datestr
   datenum_value(index_datestr)=datenum(datestr_value(index_datestr,:),'yyyymmdd');
end
yyyy_strvalue=datestr(datenum_value(1),'yyyy');
yyyy_floatvalue=str2double(datestr(datenum_value(1),'yyyy'));
doy_value=datenum_value(:) - datenum(yyyy_floatvalue,1,1) + 1;

% build LAI ASCII filename to be written
fullfilename=[PROJECT_OD 'LAI/laisen'  num2str(yyyy_floatvalue) '_' mfilename '_float.txt'];
disp(['iii : opening for writing ', fullfilename]);
[fid,message]=fopen(fullfilename,'w');
if (fid == -1)
    disp(message)
    error([ fullfilename ' can not be written'])
end
%
% write header with days of year
format_header=['Y,X' repmat(',%3.3d',1,nb_datestr) '\n'];
fprintf(fid, format_header,doy_value(:)')
%
% write data (lat, lon, lai)
format_data=['%7.3f,%8.3f' repmat(',%4.2f',1,nb_datestr) '\n'];
for index_lat=nb_lat:-1:1
   for index_lon=1:nb_lon
       value_lat = lat_value(index_lat);
       value_lon = lon_value(index_lon);
       fprintf(fid,format_data,value_lat,value_lon,lai_value(:,index_lat,index_lon));
   end
end
fclose(fid);
%
result=0;
%
end
